@@ -85,10 +85,9 @@ void CommandLine::showversion(void)
 
 void CommandLine::banner(void)
 {
-  //showversion();
   cout << "Copyright (C) 2003 Peter Brian Clements." << endl
     << "Copyright (C) 2011-2012 Marcel Partap." << endl
-    << "Copyright (C) 2012-2013 Ike Devolder." << endl
+    << "Copyright (C) 2012-2014 Ike Devolder." << endl
     << endl
     << "par2cmdline comes with ABSOLUTELY NO WARRANTY." << endl
     << endl
@@ -116,10 +115,11 @@ void CommandLine::usage(void)
     "\n"
     "Options:\n"
     "\n"
-    "  -a<file> : set the main par2 archive name\n"
+    "  -a<file> : Set the main par2 archive name\n"
     "  -b<n>    : Set the Block-Count\n"
     "  -s<n>    : Set the Block-Size (Don't use both -b and -s)\n"
     "  -r<n>    : Level of Redundancy (%%)\n"
+    "  -r<c><n> : Redundancy target size, <c>=g(iga),m(ega),k(ilo) bytes\n"
     "  -c<n>    : Recovery block count (Don't use both -r and -c)\n"
     "  -f<n>    : First Recovery-Block-Number\n"
     "  -u       : Uniform recovery file sizes\n"
@@ -128,9 +128,9 @@ void CommandLine::usage(void)
     "  -m<n>    : Memory (in MB) to use\n"
     "  -v [-v]  : Be more verbose\n"
     "  -q [-q]  : Be more quiet (-q -q gives silence)\n"
-    "  -p       : purge backup files and par files on successful recovery or\n"
+    "  -p       : Purge backup files and par files on successful recovery or\n"
     "             when no recovery is needed\n"
-    "  -R       : recurse into subdirectories (only usefull on create)\n"
+    "  -R       : Recurse into subdirectories (only useful on create)\n"
     "  --       : Treat all remaining CommandLine as filenames\n"
     "\n";
 }
@@ -159,7 +159,7 @@ bool CommandLine::Parse(int argc, char *argv[])
         {
         case 'h':
           usage();
-          break;
+          return true;
         case 'V':
           showversion();
           if (argv[0][2] != 0 &&
@@ -168,9 +168,15 @@ bool CommandLine::Parse(int argc, char *argv[])
             cout << endl;
             banner();
           }
-          break;
+          return true;
+        case '-':
+          string str = argv[0];
+          if (str == "--help")
+          {
+            usage();
+            return true;
+          }
         }
-        return true;
       }
     }
   }
@@ -230,6 +236,7 @@ bool CommandLine::Parse(int argc, char *argv[])
   }
 
   bool options = true;
+  list<string> a_filenames;
 
   while (argc>0)
   {
@@ -347,21 +354,46 @@ bool CommandLine::Parse(int argc, char *argv[])
               return false;
             }
 
-            char *p = &argv[0][2];
-            while (redundancy <= 10 && *p && isdigit(*p))
+            if (argv[0][2] == 'k'
+                || argv[0][2] == 'm'
+                || argv[0][2] == 'g'
+            )
             {
-              redundancy = redundancy * 10 + (*p - '0');
-              p++;
+              char *p = &argv[0][3];
+              while (*p && isdigit(*p))
+              {
+                redundancysize = redundancysize * 10 + (*p - '0');
+                p++;
+              }
+              switch (argv[0][2])
+              {
+                case 'g':
+                  redundancysize = redundancysize * 1024;
+                case 'm':
+                  redundancysize = redundancysize * 1024;
+                case 'k':
+                  redundancysize = redundancysize * 1024;
+                  break;
+              }
             }
-            if (redundancy > 100 || *p)
+            else
             {
-              cerr << "Invalid redundancy option: " << argv[0] << endl;
-              return false;
-            }
-            if (redundancy == 0 && recoveryfilecount > 0)
-            {
-              cerr << "Cannot set redundancy to 0 and file count > 0" << endl;
-              return false;
+              char *p = &argv[0][2];
+              while (redundancy <= 10 && *p && isdigit(*p))
+              {
+                redundancy = redundancy * 10 + (*p - '0');
+                p++;
+              }
+              if (redundancy > 100 || *p)
+              {
+                cerr << "Invalid redundancy option: " << argv[0] << endl;
+                return false;
+              }
+              if (redundancy == 0 && recoveryfilecount > 0)
+              {
+                cerr << "Cannot set redundancy to 0 and file count > 0" << endl;
+                return false;
+              }
             }
             redundancyset = true;
           }
@@ -680,8 +712,17 @@ bool CommandLine::Parse(int argc, char *argv[])
             u64 filesize = DiskFile::GetFileSize(filename);
 
             // Ignore all 0 byte files
-            if (filesize > 0)
+            if (filesize == 0)
             {
+              cout << "Skipping 0 byte file: " << filename << endl;
+            }
+            else if (a_filenames.end() != find(a_filenames.begin(), a_filenames.end(), filename))
+            {
+              cout << "Skipping duplicate filename: " << filename << endl;
+            }
+            else
+            {
+              a_filenames.push_back(filename);
               extrafiles.push_back(ExtraFile(filename, filesize));
 
               // track the total size of the source files and how
@@ -690,10 +731,6 @@ bool CommandLine::Parse(int argc, char *argv[])
               if (largestsourcesize < filesize)
               largestsourcesize = filesize;
             }
-            else
-            {
-              cout << "Skipping 0 byte file: " << filename << endl;
-            }
           } //end file exists
 
           ++fn;
